import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { ImageBaseUrl } from "@/configs/api";
import { Icon } from "@iconify/react/dist/iconify.js";
import { Avatar, AvatarImage } from "@radix-ui/react-avatar";
import moment from "moment";
import RatingStars from "./rating-stars";

interface ReviewCardProps {
	review: {
		user: {
			image?: string;
			first_name: string;
			middle_name?: string;
			last_name: string;
		};
		rating: number;
		created_at: string;
		comment: string;
	};
}

const ReviewCard = ({ review }: ReviewCardProps) => {
	return (
		<Card className="flex flex-col p-4 rounded-xlg shadow-md border-none overflow-hidden">
			<CardHeader className="flex flex-row items-start gap-4 p-4 dark:bg-gray-800">
				<Avatar className="h-16 w-16 rounded-full">
					{review?.user?.image ? (
						<AvatarImage
							className="rounded-full w-[63px] h-[63px]"
							src={ImageBaseUrl + review.user.image}
							alt={review.user.first_name}
						/>
					) : (
						<Icon icon="qlementine-icons:user-24" className="w-16 h-16 text-gray-400" />
					)}

				</Avatar>

				<div className="flex-1 text-right">
					<CardTitle className="text-lg font-semibold mb-1">
						{`${review.user.first_name} ${review.user.middle_name || ""} ${review.user.last_name}`}
					</CardTitle>
					<div className="flex items-center justify-start gap-4 text-sm text-muted-foreground">
						<span dir="ltr">{moment(review.created_at).format("DD MMMM YYYY")}</span>
						<RatingStars rating={review.rating} />
					</div>
				</div>
			</CardHeader>

			<CardContent className="p-4 flex-grow">
				<p className="text-gray-700 dark:text-gray-300 text-right leading-relaxed">
					{review.comment}
				</p>
			</CardContent>
		</Card>
	);
};

export default ReviewCard; 